@@ -22,9 +22,7 @@ typedef struct _GElektraKeyClass GElektraKeyClass;
 // clang-format off
 typedef enum {
 	GELEKTRA_KEY_FLAGS          = KEY_FLAGS,
-	GELEKTRA_KEY_NAME           = KEY_NAME,
 	GELEKTRA_KEY_VALUE          = KEY_VALUE,
-	GELEKTRA_KEY_COMMENT        = KEY_COMMENT,
 	GELEKTRA_KEY_BINARY         = KEY_BINARY,
 	GELEKTRA_KEY_SIZE           = KEY_SIZE,
 	GELEKTRA_KEY_FUNC           = KEY_FUNC,
@@ -68,9 +66,9 @@ GElektraKey * gelektra_key_gi_make (GElektraKey * key);
 void gelektra_key_gi_init (GElektraKey * key, const gchar * name, int flags, const gchar * value, const void * data, gsize data_size);
 
 /* reference handling */
-gssize gelektra_key_incref (GElektraKey * key);
-gssize gelektra_key_decref (GElektraKey * key);
-gssize gelektra_key_getref (const GElektraKey * key);
+guint16 gelektra_key_incref (GElektraKey * key);
+guint16 gelektra_key_decref (GElektraKey * key);
+guint16 gelektra_key_getref (const GElektraKey * key);
 
 /* basic methods */
 GElektraKey * gelektra_key_dup (const GElektraKey * key, elektraCopyFlags flags);
