@@ -32,7 +32,7 @@ print("")
 
 key1.setMeta("foo",     "bar")
 key1.setMeta("owner",   "manuel")
-key1.setMeta("comment", "this is my example key")
+key1.setMeta("comment/#0", "this is my example key")
 print("Keys can have metadata. We can iterate over or fetch them by name.")
 print("Meta data of Key1 with their values:")
 for meta in key1.getMeta():
