@@ -164,8 +164,6 @@ static int checkSingleReference (const Key * key, KeySet * allKeys, Key * parent
 			}
 		}
 
-		keyDel (refKey);
-
 		if (error)
 		{
 			ksDel (restrictions);
@@ -281,7 +279,6 @@ static int checkRecursiveReference (const Key * rootKey, KeySet * allKeys, Key *
 			if (reference == NULL || strlen (reference) == 0)
 			{
 				keyDel (cur);
-				keyDel (baseKey);
 				continue;
 			}
 
@@ -315,7 +312,6 @@ static int checkRecursiveReference (const Key * rootKey, KeySet * allKeys, Key *
 				keyAddBaseName (element, "#0");
 				refArray = ksNew (1, element, KS_END);
 			}
-			keyDel (baseKey);
 
 			if (!rgContains (referenceGraph, curName))
 			{
@@ -380,7 +376,6 @@ static int checkRecursiveReference (const Key * rootKey, KeySet * allKeys, Key *
 					ksDel (refArray);
 					ksDel (restrictions);
 					keyDel (curRoot);
-					keyDel (refKey);
 					keyDel (cur);
 					return ELEKTRA_PLUGIN_STATUS_ERROR;
 				}
@@ -391,7 +386,6 @@ static int checkRecursiveReference (const Key * rootKey, KeySet * allKeys, Key *
 					rgAddNode (referenceGraph, refKeyName);
 				}
 				rgAddEdge (referenceGraph, curName, refKeyName);
-				keyDel (refKey);
 			}
 			ksDel (refArray);
 			ksDel (restrictions);
