@@ -45,16 +45,16 @@ static int executeCommand (const char * cmdline)
 
 int elektraShellGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * parentKey)
 {
-	if (!elektraStrCmp (keyName (parentKey), "system/elektra/modules/shell"))
+	if (!elektraStrCmp (keyName (parentKey), "system:/elektra/modules/shell"))
 	{
 		KeySet * contract =
-			ksNew (30, keyNew ("system/elektra/modules/shell", KEY_VALUE, "shell plugin waits for your orders", KEY_END),
-			       keyNew ("system/elektra/modules/shell/exports", KEY_END),
-			       keyNew ("system/elektra/modules/shell/exports/get", KEY_FUNC, elektraShellGet, KEY_END),
-			       keyNew ("system/elektra/modules/shell/exports/set", KEY_FUNC, elektraShellSet, KEY_END),
-			       keyNew ("system/elektra/modules/shell/exports/error", KEY_FUNC, elektraShellError, KEY_END),
+			ksNew (30, keyNew ("system:/elektra/modules/shell", KEY_VALUE, "shell plugin waits for your orders", KEY_END),
+			       keyNew ("system:/elektra/modules/shell/exports", KEY_END),
+			       keyNew ("system:/elektra/modules/shell/exports/get", KEY_FUNC, elektraShellGet, KEY_END),
+			       keyNew ("system:/elektra/modules/shell/exports/set", KEY_FUNC, elektraShellSet, KEY_END),
+			       keyNew ("system:/elektra/modules/shell/exports/error", KEY_FUNC, elektraShellError, KEY_END),
 #include ELEKTRA_README
-			       keyNew ("system/elektra/modules/shell/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
+			       keyNew ("system:/elektra/modules/shell/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
 		ksAppend (returned, contract);
 		ksDel (contract);
 
@@ -70,15 +70,16 @@ int elektraShellGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * pa
 		int retVal = executeCommand (keyString (cmdKey));
 		if (retVal == -1)
 		{
-			ELEKTRA_SET_ERRORF (144, parentKey, "launching childprocess failed with %s\n", strerror (errno));
+			ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Launching childprocess failed. Reason: %s", strerror (errno));
 			return -1;
 		}
 		else if (expectedReturnKey)
 		{
 			if (atoi (keyString (expectedReturnKey)) != retVal)
 			{
-				ELEKTRA_SET_ERRORF (144, parentKey, "return value of %s doesn't match expected exit %s\n",
-						    keyString (cmdKey), keyString (expectedReturnKey));
+				ELEKTRA_SET_PLUGIN_MISBEHAVIOR_ERRORF (parentKey,
+								       "Return value of '%s' doesn't match expected exit. Reason: %s",
+								       keyString (cmdKey), keyString (expectedReturnKey));
 				return -1;
 			}
 		}
@@ -98,15 +99,16 @@ int elektraShellSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA_U
 		int retVal = executeCommand (keyString (cmdKey));
 		if (retVal == -1)
 		{
-			ELEKTRA_SET_ERRORF (144, parentKey, "launching childprocess failed with %s\n", strerror (errno));
+			ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Launching childprocess failed. Reason: %s", strerror (errno));
 			return -1;
 		}
 		else if (expectedReturnKey)
 		{
 			if (atoi (keyString (expectedReturnKey)) != retVal)
 			{
-				ELEKTRA_SET_ERRORF (144, parentKey, "return value of %s doesn't match expected exit %s\n",
-						    keyString (cmdKey), keyString (expectedReturnKey));
+				ELEKTRA_SET_PLUGIN_MISBEHAVIOR_ERRORF (parentKey,
+								       "Return value of '%s' doesn't match expected exit. Reason: %s",
+								       keyString (cmdKey), keyString (expectedReturnKey));
 				return -1;
 			}
 		}
@@ -126,15 +128,16 @@ int elektraShellError (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA
 		int retVal = executeCommand (keyString (cmdKey));
 		if (retVal == -1)
 		{
-			ELEKTRA_SET_ERRORF (144, parentKey, "launching childprocess failed with %s\n", strerror (errno));
+			ELEKTRA_SET_RESOURCE_ERRORF (parentKey, "Launching childprocess failed. Reason: %s", strerror (errno));
 			return -1;
 		}
 		else if (expectedReturnKey)
 		{
 			if (atoi (keyString (expectedReturnKey)) != retVal)
 			{
-				ELEKTRA_SET_ERRORF (144, parentKey, "return value of %s doesn't match expected exit %s\n",
-						    keyString (cmdKey), keyString (expectedReturnKey));
+				ELEKTRA_SET_PLUGIN_MISBEHAVIOR_ERRORF (parentKey,
+								       "Return value of '%s' doesn't match expected exit. Reason: %s",
+								       keyString (cmdKey), keyString (expectedReturnKey));
 				return -1;
 			}
 		}
