@@ -24,6 +24,7 @@ func TestPostMeta(t *testing.T) {
 	Assertf(t, code == http.StatusNoContent, "wrong status code: %v", code)
 
 	key := getKey(t, keyName)
+	removeKey(t, keyName)
 	Assert(t, key.Meta("postmeta") == value, "key has wrong meta value")
 }
 
@@ -31,7 +32,7 @@ func TestDeleteMetaHandler(t *testing.T) {
 	keyName := "user:/tests/elektrad/kdbmeta/delete/test"
 	value := "value"
 	meta := keyValueBody{
-		Key:   "postmeta",
+		Key:   "delmeta",
 		Value: &value,
 	}
 
@@ -42,6 +43,10 @@ func TestDeleteMetaHandler(t *testing.T) {
 	code := w.Result().StatusCode
 	Assertf(t, code == http.StatusNoContent, "wrong status code: %v", code)
 
-	metaValue := getKey(t, keyName).Meta("postmeta")
+	key := getKey(t, keyName)
+	removeKey(t, keyName)
+	Assert(t, key != nil, "key not found")
+
+	metaValue := key.Meta(meta.Key)
 	Assertf(t, metaValue == "", "key meta value is not empty: %q", metaValue)
 }
